@@ -698,11 +698,11 @@ class Tag:
    # Both URLFrame and UserURLFrame objects are returned.  UserURLFrames
    # add a description and encoding, and have a different frame ID.
    def getURLs(self):
-      urls = list();
-      for fid in URL_FIDS:
-         urls.extend(self.frames[fid]);
-      urls.extend(self.frames[USERURL_FID]);
-      return urls;
+       urls = []
+       for fid in URL_FIDS:
+           urls.extend(self.frames[fid])
+       urls.extend(self.frames[USERURL_FID])
+       return urls
 
    def getUserTextFrames(self):
       return self.frames[USERTEXT_FID];
@@ -891,9 +891,23 @@ class Tag:
          self.frames.setUserTextFrame(self.strToUnicode(text),
                                       self.strToUnicode(desc), self.encoding);
 
+   def addUserURLFrame(self, desc, url):
+      if not url:
+         u_frames = self.frames[USERURL_FID]
+         for u in u_frames:
+            if u.description == desc:
+               self.frames.remove(u)
+               break
+      else:
+         self.frames.setUserURLFrame(str(url), self.strToUnicode(desc),
+                                     self.encoding)
+
    def removeUserTextFrame(self, desc):
       self.addUserTextFrame(desc, "")
 
+   def removeUserURLFrame(self, desc):
+      self.addUserURLFrame(desc, "")
+
    def removeComments(self):
        return self.frames.removeFramesByID(COMMENT_FID);
 
@@ -1007,6 +1021,12 @@ class Tag:
        else:
           self.frames.setTextFrame(fid, self.strToUnicode(txt), self.encoding);
 
+   def setURLFrame(self, fid, url):
+       if not url:
+          self.frames.removeFramesByID(fid)
+       else:
+          self.frames.setURLFrame(fid, url)
+
    def setTextEncoding(self, enc):
        if enc != LATIN1_ENCODING and enc != UTF_16_ENCODING and\
           enc != UTF_16BE_ENCODING and enc != UTF_8_ENCODING:
@@ -1523,7 +1543,7 @@ class Genre:
 
       # Non standard, but witnessed.
       # Match genre alone. e.g. Rap, Rock, blues, 'Rock|Punk|Pop-Punk', etc
-      regex = re.compile("^[A-Z 0-9+/\-\|!&]+\00*$", re.IGNORECASE)
+      regex = re.compile("^[A-Z 0-9+/\-\|!&'\.]+\00*$", re.IGNORECASE)
       if regex.match(genreStr):
          self.setName(genreStr);
          return;
